@@ -25,3 +25,5 @@ class Order:
     order_type: OrderType
     status: Status
     interval: int
+    price: BigFloat = field(default=None)
+    value: BigFloat = field(default=None)
